@@ -27,24 +27,19 @@ extern crate getopts;
 use std::fs::File;
 use std::io::BufReader;
 use std::io::BufRead;
-use std::env;
 
 use fasten::fasten_base_options;
+use fasten::fasten_base_options_matches;
 use fasten::logmsg;
 
 fn main(){
-    let args: Vec<String> = env::args().collect();
     let mut opts = fasten_base_options();
 
     // script-specific options
     opts.optopt("m","max-quality","The maximum quality at which a base will be transformed to 'N'","INT");
 
-    let matches = opts.parse(&args[1..]).expect("ERROR: could not parse parameters");
-
-    if matches.opt_present("help") {
-        println!("Transforms any low-quality base to 'N'\n{}", opts.usage(&opts.short_usage(&args[0])));
-        std::process::exit(0);
-    }
+    let matches = fasten_base_options_matches("Transforms any low-quality base to 'N'.", opts);
+    
     if matches.opt_present("paired-end") {
         logmsg("WARNING: --paired-end is not utilized in this script");
     }
