@@ -32,26 +32,21 @@ extern crate regex;
 use std::fs::File;
 use std::io::BufReader;
 use std::io::BufRead;
-use std::env;
 
 use regex::Regex;
 
 use fasten::fasten_base_options;
+use fasten::fasten_base_options_matches;
 use fasten::logmsg;
 
 fn main(){
-    let args: Vec<String> = env::args().collect();
     let mut opts = fasten_base_options();
     // Options specific to this script
     opts.optopt("f","find","Regular expression (default: '.')","STRING");
     opts.optopt("r","replace","String to replace each match","STRING");
     opts.optopt("w","which","Which field to match on? ID, SEQ, QUAL. Default: SEQ","STRING");
 
-    let matches = opts.parse(&args[1..]).expect("ERROR: could not parse parameters");
-    if matches.opt_present("help") {
-        println!("Streaming editor for fastq data using a find/replace.\n{}", opts.usage(&opts.short_usage(&args[0])));
-        std::process::exit(0);
-    }
+    let matches = fasten_base_options_matches("Streaming editor for fastq data using a find/replace.", opts);
 
     if matches.opt_present("paired-end") {
         logmsg("WARNING: --paired-end is not utilized in this script");
